# Release notes for visfem 0.0.1
![visfem](./docs/images/favicon/visfem-100x100-300dpi.png)

We are pleased to release the next version of visfem including the
following changes:

## Features & fixes
- initial release

Your visfem team
